Attribute VB_Name = "GPIB32"
Option Explicit
'*********************************************************************
'                                                           01-17-07
'      GPIB Library
'
'  File: GPIB-32.BAS
'
'
' This file contains the Visual BASIC (32 bit) declarations for all
' GPIB library commands.   This file should be imported via Visual
' BASIC's Load File command (from the Project menu).
'
' This file is ONLY for use with the 32 bit version of Visual BASIC.  If
' you are using the 16 bit version, then include GPIB-16.BAS instead.
'
' Compiled files produced with ICS's GPIB-32.BAS and ICSVB.BAS files
' will work the same as the compiled files built with National Instruments'
' NIGLOBAL.BAS and VBIB.BAS files.
'
'***********************************************************************
' 01-02-07 Removed result line in FindRQS
' 01-08-07 Use sync rd/wrt/cmd commands until remapping problem solved
' 01-09-07 ibrd modified to execute ibrdi calls to match NI
' 01-17-07 ibcEndBitIsNormal replaced ibcNoEndBitOnEos

'COMMON SHARED /GPIBVARS/ IBSTA%, IBERR%, IBCNT%, IBCNTL&
Global ibsta%, iberr%, ibcnt%, ibcntl&
Global GPIBInProgress%

' GPIB Commands
Global Const GTL = &H1
Global Const SDC = &H4
Global Const PPC = &H5
Global Const GETT = &H8
Global Const TCT = &H9
Global Const LLO = &H11
Global Const DCL = &H14
Global Const PPU = &H15
Global Const SPE = &H18
Global Const SPD = &H19
Global Const UNL = &H3F
Global Const UNT = &H5F
Global Const PPE = &H60
Global Const PPD = &H70


' Bit specifiers for ibsta status variable and wait mask
Global Const EERR = &H8000  ' Error detected
Global Const TIMO = &H4000  ' Timeout
Global Const EEND = &H2000  ' EOI or EOS detected
Global Const SRQI = &H1000  ' SRQ detected by CIC
Global Const RQS = &H800    ' Device needs service
Global Const SPOLL = &H400  ' Board has been serially polled
Global Const eevent = &H200 ' An event has occured
Global Const CMPL = &H100   ' I/O completed
Global Const LOK = &H80     ' Local lockout state
Global Const RREM = &H40    ' Remote state
Global Const CIC = &H20     ' Controller-in-Charge
Global Const AATN = &H10    ' Attention asserted
Global Const TACS = &H8     ' Talker active
Global Const LACS = &H4     ' Listener active
Global Const DTAS = &H2     ' Device trigger state
Global Const DCAS = &H1     ' Device clear state


' Error codes returned to IBERR variable
Global Const EDVR = 0     ' DOS error
Global Const ECIC = 1     ' Board must be CIC for this function
Global Const ENOL = 2     ' No listeners detected
Global Const EADR = 3     ' Board not addressed correctly
Global Const EARG = 4     ' Invalid argument passed to function
Global Const ESAC = 5     ' Function requires GPIB board to be SC
Global Const EABO = 6     ' I/O operation aborted
Global Const ENEB = 7     ' Invalid board specified
Global Const EOIP = 10    ' I/O operation already running
Global Const ECAP = 11    ' Board does not have requested capability
Global Const EFSO = 12    ' Error returned from file system
Global Const EBUS = 14    ' Command error on bus
Global Const ESTB = 15    ' Serial poll response byte lost
Global Const ESRQ = 16    ' SRQ is still asserted
Global Const ETAB = 20    ' No device responding with ETAB

Global Const EINT = 247   ' No interrupt configured on board.
Global Const EWMD = 248   ' Windows is not in enhanced mode
Global Const EVDD = 249   ' CBGPIB.386 is not installed
Global Const EOVR = 250   ' Buffer overflow
Global Const ESML = 251   ' Two library calls running simultaneously
Global Const ECFG = 252   ' Board type doesn't match GPIB.CFG
Global Const ETMR = 253   ' No Windows timers available
Global Const ESLC = 254   ' No Windows selectors available
Global Const EBRK = 255   ' Ctrl-Break pressed, exiting program


' EOS mode bits
Global Const BIN = &H1000
Global Const XEOS = &H800
Global Const REOS = &H400


' Timeout code for ibtmo function
Global Const TNONE = 0      ' No timeout
Global Const T10us = 1      ' 10 usec
Global Const T30us = 2      ' 30 usec
Global Const T100us = 3     ' 100 usec
Global Const T300us = 4     ' 300 usec
Global Const T1ms = 5       ' 1 msec
Global Const T3ms = 6       ' 3 msec
Global Const T10ms = 7      ' 10 msec
Global Const T30ms = 8      ' 30 msec
Global Const T100ms = 9     ' 100 msec
Global Const T300ms = 10    ' 300 msec
Global Const T1s = 11       ' 1 sec
Global Const T3s = 12       ' 3 sec
Global Const T10s = 13      ' 10 sec
Global Const T30s = 14      ' 30 sec
Global Const T100s = 15     ' 100 sec
Global Const T300s = 16     ' 300 sec
Global Const T1000s = 17    ' 1000 sec

'  IBLN Constants
Global Const NO_SAD = 0
Global Const ALL_SAD = -1


' Miscellaneous
Global Const S = &H8             ' parallel poll bit
Global Const LF = &HA            ' linefeed character
Global Const NOADDR = &HFFFF     'Terminator for address list
Global Const NULLend = 0         'Send() EOTMODE - Do nothing at the end of a transfer.
Global Const NLend = 1           'Send() EOTMODE - Send NL with EOI after a transfer.
Global Const DABend = 2          'Send() EOTMODE - Send EOI with the last DAB.
Global Const STOPend = &H100     'Receive()( termination
Global Const EventDTAS = 1       'used by IBEVENT()
Global Const EventDCAS = 2       'used by IBEVENT()


' The following constants are used with ibconfig() to select a
' configurable option.
Global Const IbcPAD = &H1             ' Primary address
Global Const IbcSAD = &H2             ' Secondary address
Global Const IbcTMO = &H3             ' Timeout
Global Const IbcEOT = &H4             ' Send EOI with last byte
Global Const IbcPPC = &H5             ' Parallel Poll Configure
Global Const IbcREADDR = &H6          ' Repeat Addressing
Global Const IbcAUTOPOLL = &H7        ' Disable automatic serial poll
Global Const IbcCICPROT = &H8         ' Use CIC Protocol
Global Const IbcIRQ = &H9             ' Interrupt level (or 0 for none)
Global Const IbcSC = &HA              ' Board is system controller
Global Const IbcSRE = &HB             ' Assert SRE for dev calls
Global Const IbcEOSrd = &HC           ' Terminate read on EOS
Global Const IbcEOSwrt = &HD          ' Send EOI with EOS
Global Const IbcEOScmp = &HE          ' Use 7 or 8-bit compare with EOS
Global Const IbcEOSchar = &HF         ' EOS character
Global Const IbcPP2 = &H10            ' Use PP mode 2
Global Const IbcTIMING = &H11         ' Normal, High or Very High Speed
Global Const IbcDMA = &H12            ' DMA channel (or 0 for none)
Global Const IbcReadAdjust = &H13     ' Swap bytes on read
Global Const IbcWriteAdjust = &H14    ' Swap bytes on write
Global Const IbcEventQueue = &H15     ' Use event queue
Global Const IbcSPollBit = &H16       ' Serial poll bit used
Global Const IbcSendLLO = &H17        ' Automatically send LLO
Global Const IbcSPollTime = &H18      ' Serial poll timeout
Global Const IbcPPollTime = &H19      ' Parallel poll timeout
Global Const IbcEndBitIsNormal = &H1A  ' Don't set end bit on EOS
Global Const IbcBNA = &H200           ' A device's access board.
Global Const IbcBaseAddr = &H201      ' A GPIB board's base I/O address.

' CBP config items - Don't exist in NI software
Global Const IbcBoardType = &H300     ' Board type
Global Const IbcChipType = &H301      ' ChipType
Global Const IbcSlotNum = &H302       ' Slot Number
Global Const IbcPCIIndex = &H303      ' PCI Index
Global Const IbcBaseAdr2 = &H304      ' 2nd base address for PCI board
Global Const IbcUseFIFOs = &H305      ' When to use FIFOs


' These are provided for compatability with NI's library
Global Const IbaPAD = &H1
Global Const IbaSAD = &H2
Global Const IbaTMO = &H3
Global Const IbaEOT = &H4
Global Const IbaPPC = &H5
Global Const IbaREADDR = &H6
Global Const IbaAUTOPOLL = &H7
Global Const IbaCICPROT = &H8
Global Const IbaIRQ = &H9
Global Const IbaSC = &HA
Global Const IbaSRE = &HB
Global Const IbaEOSrd = &HC
Global Const IbaEOSwrt = &HD
Global Const IbaEOScmp = &HE
Global Const IbaEOSchar = &HF
Global Const IbaPP2 = &H10
Global Const IbaTIMING = &H11
Global Const IbaDMA = &H12
Global Const IbaReadAdjust = &H13
Global Const IbaWriteAdjust = &H14
Global Const IbaEventQueue = &H15
Global Const IbaSPollBit = &H16
Global Const IbaSendLLO = &H17
Global Const IbaSPollTime = &H18
Global Const IbaPPollTime = &H19
Global Const IbaEndBitIsNormal = &H1A
Global Const IbaBNA = &H200
Global Const IbaBaseAddr = &H201

' CBI config items - Don't exist in NI software
Global Const IbaBoardType = &H300
Global Const IbaChipType = &H301
Global Const IbaSlotNum = &H302
Global Const IbaPCIIndex = &H303
Global Const IbaBaseAdr2 = &H304
Global Const IbaUseFIFOs = &H305


' These bits specify which lines can be monitored by IBLINES
Global Const ValidDAV = &H1
Global Const ValidNDAC = &H2
Global Const ValidNRFD = &H4
Global Const ValidIFC = &H8
Global Const ValidREN = &H10
Global Const ValidSRQ = &H20
Global Const ValidATN = &H40
Global Const ValidEOI = &H80

' These bits specify the current state of each GPIB line
Global Const BusDAV = &H100
Global Const BusNDAC = &H200
Global Const BusNRFD = &H400
Global Const BusIFC = &H800
Global Const BusREN = &H1000
Global Const BusSRQ = &H2000
Global Const BusATN = &H4000
Global Const BusEOI = &H8000



' GPIB-32.DLL routines
Declare Function DLLibask Lib "gpib-32.dll" Alias "ibask" (ByVal board&, ByVal item&, ByRef value&) As Integer
Declare Function DLLibbna Lib "gpib-32.dll" Alias "ibbnaA" (ByVal Device&, ByVal boardname$) As Integer
Declare Function DLLibcac Lib "gpib-32.dll" Alias "ibcac" (ByVal Device&, ByVal sync&) As Integer
Declare Function DLLibclr Lib "gpib-32.dll" Alias "ibclr" (ByVal Device&) As Integer
Declare Function DLLibcmd Lib "gpib-32.dll" Alias "ibcmd" (ByVal Device&, ByVal cmnd$, ByVal cnt&) As Integer
Declare Function DLLibcmda Lib "gpib-32.dll" Alias "ibcmda" (ByVal Device&, ByVal cmnd$, ByVal cnt&) As Integer
Declare Function DLLibconfig Lib "gpib-32.dll" Alias "ibconfig" (ByVal Device&, ByVal item&, ByVal val&) As Integer
Declare Function DLLibdev Lib "gpib-32.dll" Alias "ibdev" (ByVal Device&, ByVal pad&, ByVal sad&, ByVal timeout&, ByVal eot&, ByVal eos&) As Integer
Declare Function DLLibdma Lib "gpib-32.dll" Alias "ibdma" (ByVal Device&, ByVal dma&) As Integer
Declare Function DLLibeos Lib "gpib-32.dll" Alias "ibeos" (ByVal Device&, ByVal eos&) As Integer
Declare Function DLLibeot Lib "gpib-32.dll" Alias "ibeot" (ByVal Device&, ByVal eot&) As Integer
Declare Function DLLibevent Lib "gpib-32.dll" Alias "ibevent" (ByVal Device&, ByVal eevent&) As Integer
Declare Function DLLibfind Lib "gpib-32.dll" Alias "ibfindA" (ByVal devname$) As Integer
Declare Function DLLibgts Lib "gpib-32.dll" Alias "ibgts" (ByVal Device&, ByVal handshake&) As Integer
Declare Function DLLibist Lib "gpib-32.dll" Alias "ibist" (ByVal Device&, ByVal statusbit&) As Integer
Declare Function DLLibinit Lib "gpib-32.dll" Alias "ibinit" (ByVal Device&) As Integer
Declare Function DLLiblines Lib "gpib-32.dll" Alias "iblines" (ByVal Device&, ByRef clines&) As Integer
Declare Function DLLibln Lib "gpib-32.dll" Alias "ibln" (ByVal Device&, ByVal pad&, ByVal sad&, ByRef listenflag%) As Integer
Declare Function DLLibloc Lib "gpib-32.dll" Alias "ibloc" (ByVal Device&) As Integer
Declare Function DLLibonl Lib "gpib-32.dll" Alias "ibonl" (ByVal Device&, ByVal online&) As Integer
Declare Function DLLibpad Lib "gpib-32.dll" Alias "ibpad" (ByVal Device&, ByVal address&) As Integer
Declare Function DLLibpct Lib "gpib-32.dll" Alias "ibpct" (ByVal Device&) As Integer
Declare Function DLLibppc Lib "gpib-32.dll" Alias "ibppc" (ByVal Device&, ByVal Cmd&) As Integer
Declare Function DLLibptrs Lib "gpib-32.dll" Alias "ibptrs" (ibstaPtr%, iberrPtr%, ibcntPtr%, ibcntlPtr&) As Integer
Declare Function DLLibrd Lib "gpib-32.dll" Alias "ibrd" (ByVal Device&, readstr As Any, ByVal rdcount&) As Integer
Declare Function DLLibrda Lib "gpib-32.dll" Alias "ibrda" (ByVal Device&, ByVal readstr$, ByVal rdcount&) As Integer
Declare Function DLLibrdf Lib "gpib-32.dll" Alias "ibrdfA" (ByVal Device&, ByVal filename$) As Integer
Declare Function DLLibrpp Lib "gpib-32.dll" Alias "ibrpp" (ByVal Device&, ByVal resp$) As Integer
Declare Function DLLibrsc Lib "gpib-32.dll" Alias "ibrsc" (ByVal Device&, ByVal ctrl&) As Integer
Declare Function DLLibrsp Lib "gpib-32.dll" Alias "ibrsp" (ByVal Device&, ByVal resp$) As Integer
Declare Function DLLibrsv Lib "gpib-32.dll" Alias "ibrsv" (ByVal Device&, ByVal resp&) As Integer
Declare Function DLLibsad Lib "gpib-32.dll" Alias "ibsad" (ByVal Device&, ByVal sad&) As Integer
Declare Function DLLibsic Lib "gpib-32.dll" Alias "ibsic" (ByVal Device&) As Integer
Declare Function DLLibsre Lib "gpib-32.dll" Alias "ibsre" (ByVal Device&, ByVal ren&) As Integer
Declare Function DLLibstop Lib "gpib-32.dll" Alias "ibstop" (ByVal Device&) As Integer
Declare Function DLLibtmo Lib "gpib-32.dll" Alias "ibtmo" (ByVal Device&, ByVal tmo&) As Integer
Declare Function DLLibtrg Lib "gpib-32.dll" Alias "ibtrg" (ByVal Device%) As Integer
Declare Function DLLibwait Lib "gpib-32.dll" Alias "ibwait" (ByVal Device&, ByVal mask&) As Integer
Declare Function DLLibwrt Lib "gpib-32.dll" Alias "ibwrt" (ByVal Device&, ByVal writestr$, ByVal cnt&) As Integer
Declare Function DLLibwrta Lib "gpib-32.dll" Alias "ibwrta" (ByVal Device&, ByVal writestr$, ByVal cnt&) As Integer
Declare Function DLLibwrtf Lib "gpib-32.dll" Alias "ibwrtfA" (ByVal Device&, ByVal filename$) As Integer
Declare Function DLLibwrti Lib "gpib-32.dll" Alias "ibwrti" (ByVal Device&, ByRef iray&(), ByVal cnt&) As Integer
Declare Function DLLibwrtia Lib "gpib-32.dll" Alias "ibwrtia" (ByVal Device&, ByRef iray&(), ByVal cnt&) As Integer
Declare Function DLLThreadIbsta Lib "gpib-32.dll" Alias "ThreadIbsta" () As Integer
Declare Function DLLThreadIberr Lib "gpib-32.dll" Alias "ThreadIberr" () As Integer
Declare Function DLLThreadIbcnt Lib "gpib-32.dll" Alias "ThreadIbcnt" () As Integer
Declare Function DLLThreadIbcntl Lib "gpib-32.dll" Alias "ThreadIbcntl" () As Long

Declare Sub DLLAllSpoll Lib "gpib-32.dll" Alias "AllSpoll" (ByVal dev&, ByRef adrlist%, ByRef results%)
Declare Sub DLLDevClear Lib "gpib-32.dll" Alias "DevClear" (ByVal dev&, ByVal adr%)
Declare Sub DLLDevClearList Lib "gpib-32.dll" Alias "DevClearList" (ByVal ByValdev&, ByRef adrlist%)
Declare Sub DLLEnableLocal Lib "gpib-32.dll" Alias "EnableLocal" (ByVal dev&, ByRef adrlist%)
Declare Sub DLLEnableRemote Lib "gpib-32.dll" Alias "EnableRemote" (ByVal dev&, ByRef adrlist%)
Declare Sub DLLFindLstn Lib "gpib-32.dll" Alias "FindLstn" (ByVal dev As Long, ByRef adrlist As Any, ByRef results As Any, ByVal limit As Long)
Declare Sub DLLFindRQS Lib "gpib-32.dll" Alias "FindRQS" (ByVal dev&, ByRef adrlist As Any, ByRef result%)
Declare Sub DLLPassControl Lib "gpib-32.dll" Alias "PassControl" (ByVal dev&, ByVal adr%)
Declare Sub DLLPPoll Lib "gpib-32.dll" Alias "PPoll" (ByVal dev&, ByRef result%)
Declare Sub DLLPPollConfig Lib "gpib-32.dll" Alias "PollConfig" (ByVal dev&, ByVal adr%, ByVal lline&, ByVal sense&)
Declare Sub DLLPPollUnconfig Lib "gpib-32.dll" Alias "PollUnconfig" (ByVal dev&, ByRef adrlist%)
Declare Sub DLLRcvRespMsg Lib "gpib-32.dll" Alias "RcvRespMsg" (ByVal dev&, ByVal buf$, ByVal cnt&, ByVal term&)
Declare Sub DLLReadStatusByte Lib "gpib-32.dll" Alias "ReadStatusByte" (ByVal dev&, ByVal adr%, ByRef result%)
Declare Sub DLLReceive Lib "gpib-32.dll" Alias "Receive" (ByVal dev&, ByVal adr%, ByVal buf$, ByVal count&, ByVal term&)
Declare Sub DLLReceiveSetup Lib "gpib-32.dll" Alias "ReceiveSetup" (ByVal dev&, ByVal adr%)
Declare Sub DLLResetSys Lib "gpib-32.dll" Alias "ResetSys" (ByVal dev&, ByRef adrlist%)
Declare Sub DLLSend Lib "gpib-32.dll" Alias "Send" (ByVal dev&, ByVal adr%, ByVal buf$, ByVal cnt&, ByVal term&)
Declare Sub DLLSendCmds Lib "gpib-32.dll" Alias "SendCmds" (ByVal dev&, ByVal cmdbuf$, ByVal cnt&)
Declare Sub DLLSendDataBytes Lib "gpib-32.dll" Alias "SendDataBytes" (ByVal dev&, ByVal buf$, ByVal cnt&, ByVal term&)
Declare Sub DLLSendIFC Lib "gpib-32.dll" Alias "SendIFC" (ByVal dev&)
Declare Sub DLLSendList Lib "gpib-32.dll" Alias "SendList" (ByVal dev&, ByRef adr%, ByVal buf$, ByVal cnt&, ByVal term&)
Declare Sub DLLSendLLO Lib "gpib-32.dll" Alias "SendLLO" (ByVal dev&)
Declare Sub DLLSendSetup Lib "gpib-32.dll" Alias "SendSetup" (ByVal dev&, ByRef adrlist%)
Declare Sub DLLSetRWLS Lib "gpib-32.dll" Alias "SetRWLS" (ByVal dev&, ByRef adrlist%)
Declare Sub DLLTestSRQ Lib "gpib-32.dll" Alias "TestSRQ" (ByVal dev&, ByRef result%)
Declare Sub DLLTestSys Lib "gpib-32.dll" Alias "TestSys" (ByVal dev&, ByRef adrlist%, ByRef results%)
Declare Sub DLLTrigger Lib "gpib-32.dll" Alias "Trigger" (ByVal dev&, ByVal adr%)
Declare Sub DLLTriggerList Lib "gpib-32.dll" Alias "TriggerList" (ByVal dev&, ByRef adrlist%)
Declare Sub DLLWaitSRQ Lib "gpib-32.dll" Alias "WaitSRQ" (ByVal dev&, ByRef result%)




'************************
' 488.1 Functions
'************************

Function ilask(ByVal dev%, ByVal opt%, ByRef rval%) As Integer
    Dim result&
    ilask% = DLLibask(dev%, opt%, result&)
    rval% = Int(result&)
    ibcnt% = ibcntl&
End Function

Function ilbna(ByVal dev%, ByVal devname$) As Integer
    ilbna = DLLibbna(dev%, devname$)
    Call copy_globals
End Function

Function ilcac(ByVal dev%, ByVal v%) As Integer
    ilcac = DLLibcac(dev%, v%)
    Call copy_globals
End Function

Function ilclr(ByVal dev%) As Integer
    ilclr = DLLibclr(dev%)
    Call copy_globals
End Function

Function ilcmd(ByVal dev%, ByVal buf$, ByVal cnt&) As Integer
    ilcmd = DLLibcmd(dev%, buf$, cnt&)
    Call copy_globals
End Function

Function ilcmda(ByVal dev%, ByVal buf$, ByVal cnt&) As Integer
    ilcmda = DLLibcmd(dev%, buf$, cnt&)
    'when the buffer remapping problem is solved, use
    'ilcmda = DLLibcmd(dev%, buf$, cnt&)
    Call copy_globals
End Function

Function ilconfig(ByVal bdid%, ByVal opt%, ByVal v%) As Integer
    ilconfig = DLLibconfig(bdid%, opt%, v%)
    Call copy_globals
End Function

Function ildev(ByVal bdid%, ByVal pad%, ByVal sad%, ByVal tmo%, ByVal eot%, ByVal eos%) As Integer
    ildev = DLLibdev(bdid%, pad%, sad%, tmo%, eot%, eos%)
    Call copy_globals
End Function

Function ildma(ByVal dev%, ByVal v%) As Integer
    ildma = DLLibdma(dev%, v%)
    Call copy_globals
End Function

Function ileos(ByVal dev%, ByVal v%) As Integer
    ileos = DLLibeos(dev%, v%)
    Call copy_globals
End Function

Function ileot(ByVal dev%, ByVal v%) As Integer
    ileot% = DLLibeot(dev%, v%)
    Call copy_globals
End Function

Function ilevent(ByVal dev%, ByVal eevent%) As Integer
    ilevent% = DLLibevent(dev%, eevent%)
    Call copy_globals
End Function

Function ilfind(ByVal devname$) As Integer
    ilfind% = DLLibfind(devname$)
    Call copy_globals
End Function

Function ilgts(ByVal dev%, ByVal v%) As Integer
    ilgts% = DLLibgts(dev%, v%)
    Call copy_globals
End Function

Function ilinit(ByVal dev%) As Integer
    ilinit% = DLLibinit(dev%)
    Call copy_globals
End Function

Function ilist(ByVal dev%, ByVal v%) As Integer
    ilist% = DLLibist(dev%, v%)
    Call copy_globals
End Function

Function illines(ByVal dev%, ByRef lines%) As Integer
    Dim res&
    illines% = DLLiblines(dev%, res&)
    lines% = res&
    Call copy_globals
End Function

Function illn(ByVal dev%, ByVal pad%, ByVal sad%, ByRef listener%) As Integer
    illn% = DLLibln(dev%, pad%, sad%, listener%)
    Call copy_globals
End Function

Function illoc(ByVal dev%) As Integer
    illoc% = DLLibloc(dev%)
    Call copy_globals
End Function

Function ilonl(ByVal dev%, ByVal v%) As Integer
    ilonl% = DLLibonl(dev%, v%)
    Call copy_globals
End Function

Function ilpad(ByVal dev%, ByVal v%) As Integer
    ilpad% = DLLibpad(dev%, v%)
    Call copy_globals
End Function

Function ilpct(ByVal dev%) As Integer
    ilpct% = DLLibpct(dev%)
    Call copy_globals
End Function

Function ilppc(ByVal dev%, ByVal v%) As Integer
    ilppc% = DLLibppc(dev%, v%)
    Call copy_globals
End Function

Function ilrd(ByVal dev%, buf As String, ByVal cnt&) As Integer
    ilrd% = DLLibrd(dev%, ByVal buf, cnt&)
    Call copy_globals
End Function

Function ilrda(ByVal dev%, buf As String, ByVal cnt&) As Integer
' Call the 32-bit DLL.
    ilrda% = DLLibrd(dev%, ByVal buf, cnt&)
    
' When Visual Basic remapping buffer problem solved, use this:
    'ilrda% = DLLibrda(dev%, buf$, cnt&)
    Call copy_globals
End Function

Function ilrdf(ByVal dev%, ByVal filename$) As Integer
    ilrdf% = DLLibrdf(dev%, filename$)
    Call copy_globals
End Function

Function ilrdi(ByVal dev%, ibuf() As Integer, ByVal cnt&) As Integer
    ilrdi% = DLLibrd(dev%, ibuf(0), cnt&)
    Call copy_globals
End Function

Function ilrdia(ByVal dev%, ibuf() As Integer, ByVal cnt&) As Integer
' Call the 32-bit DLL.
    ilrdia% = DLLibrd(dev%, ibuf(0), cnt&)

' When Visual Basic remapping buffer problem solved, use this:
    'ilrdia% = DLLibrdi(dev%, ibuf&(0), cnt&)
    Call copy_globals
End Function

Function ilrpp(ByVal dev%, ByRef ppr%) As Integer
    Dim resp$
    resp$ = " "
    ilrpp% = DLLibrpp(dev%, resp$)
    ppr = Int(Left$(resp, 1&))
    Call copy_globals
End Function

Function ilrsc(ByVal dev%, ByVal v%) As Integer
    ilrsc% = DLLibrsc(dev%, v%)
    Call copy_globals
End Function

Function ilrsp(ByVal dev%, ByRef rsp%) As Integer
    Dim resp$
    resp$ = " "
    ilrsp% = DLLibrsp(dev%, resp$)
    rsp% = Int(Left$(resp, 1&))
    Call copy_globals
End Function

Function ilrsv(ByVal dev%, ByVal v%) As Integer
    ilrsv% = DLLibrsv(dev%, v%)
    Call copy_globals
End Function

Function ilsad(ByVal dev%, ByVal v%) As Integer
    ilsad% = DLLibsad(dev%, v%)
    Call copy_globals
End Function

Function ilsic(ByVal dev%) As Integer
    ilsic% = DLLibsic(dev%)
    Call copy_globals
End Function

Function ilsre(ByVal dev%, ByVal v%) As Integer
    ilsre% = DLLibsre(dev%, v%)
    Call copy_globals
End Function

Function ilstop(ByVal dev%) As Integer
    ilstop% = DLLibstop(dev%)
    Call copy_globals
End Function

Function ILTMO(ByVal dev%, ByVal v%) As Integer
    ILTMO% = DLLibtmo(dev%, v%)
    Call copy_globals
End Function

Function iltrg(ByVal dev%) As Integer
    iltrg% = DLLibtrg(dev%)
    Call copy_globals
End Function

Function ilwait(ByVal dev%, ByVal mask%) As Integer
    ilwait% = DLLibwait(dev%, mask%)
    Call copy_globals
End Function

Function ilwrt(ByVal dev%, ByVal buf$, ByVal cnt&) As Integer
    ilwrt% = DLLibwrt(dev%, buf$, cnt&)
    Call copy_globals
End Function

Function ilwrta(ByVal dev%, ByVal buf$, ByVal cnt&) As Integer
' Call the 32-bit DLL.
    ilwrta% = DLLibwrt(dev%, buf$, cnt&)
    
' When the Visual Basic remapping solved, use this:
    'ilwrta% = DLLibwrt(dev%, buf$, cnt&)
    Call copy_globals
End Function

Function ilwrtf(ByVal dev%, ByVal filename$) As Integer
    ilwrtf% = DLLibwrtf(dev%, filename$)
    Call copy_globals
End Function

Function ilwrti(ByVal dev%, ByRef ibuf&(), ByVal cnt&) As Integer
    ilwrti% = DLLibwrti(dev%, ibuf&(), cnt&)
    Call copy_globals
End Function

Function ilwrtia(ByVal dev%, ByRef ibuf&(), ByVal cnt&) As Integer
' Call the 32-bit DLL.
    ilwrtia% = DLLibwrti(dev%, ibuf&(), cnt&)
    
' When the Visual Basic remapping solved, use this:
    'ilwrtia% = DLLibwrti(dev%, ibuf&(), cnt&)
    Call copy_globals
End Function


'************************
' 488.1 Subroutines
'************************

Function ibask(ByVal dev%, ByVal opt%, ByRef rval%) As Integer
    Dim result&
    ibask = DLLibask(dev%, opt%, result&)
    rval% = result&
    Call copy_globals
End Function

Function ibbna(ByVal dev%, devname$) As Integer
    ibbna = DLLibbna(dev%, devname$)
    Call copy_globals
End Function

Function ibcac(ByVal dev%, ByVal v%) As Integer
    ibcac = DLLibcac(dev%, v%)
    Call copy_globals
End Function

Function ibclr(ByVal dev%) As Integer
    ibclr = DLLibclr(dev%)
    Call copy_globals
End Function

Function ibcmd(ByVal dev%, ByVal buf$) As Integer
    Dim length&
    length& = Len(buf$)
    ibcmd = DLLibcmd(dev%, buf$, length&)
    Call copy_globals
End Function

Function ibcmda(ByVal dev%, ByVal buf$) As Integer
    Dim length&
    length& = Len(buf$)
    ' Call the 32-bit DLL.
    ibcmda = DLLibcmd(dev%, buf$, length&)
' When Visual Basic remapping buffer problem is solved, use this:
   ' ibcmda = DLLibcmda(dev%, buf$, length&)
    Call copy_globals
End Function

Function ibconfig(ByVal bdid%, ByVal opt%, ByVal v%) As Integer
    ibconfig = DLLibconfig(bdid%, opt%, v%)
    Call copy_globals
End Function

Function ibdev(ByVal bdid%, ByVal pad%, ByVal sad%, ByVal tmo%, ByVal eot%, ByVal eos%, ByRef dev%) As Integer
    dev% = DLLibdev(bdid%, pad%, sad%, tmo%, eot%, eos%)
    ibdev = dev%
    Call copy_globals
End Function

Function ibdma(ByVal dev%, ByVal v%) As Integer
    ibdma = DLLibdma(dev%, v%)
    Call copy_globals
End Function

Function ibeos(ByVal dev%, ByVal v%) As Integer
    ibeos = DLLibeos(dev%, v%)
    Call copy_globals
End Function

Function ibeot(ByVal dev%, ByVal v%) As Integer
    ibeot = DLLibeot(dev%, v%)
    Call copy_globals
End Function

Function ibevent(ByVal dev%, ByVal eevent%) As Integer
    ibevent = DLLibevent(dev%, eevent%)
    Call copy_globals
End Function

Function ibfind(ByVal devname$, Optional ByRef dev%) As Integer
    Dim result%
    result% = DLLibfind(devname$)
    If Not IsMissing(dev%) Then
        dev% = result%
    End If
    ibfind = result%
    Call copy_globals
End Function

Function ibgts(ByVal dev%, ByVal v%) As Integer
    ibgts = DLLibgts(dev%, v%)
    Call copy_globals
End Function

Function ibinit(ByVal dev%) As Integer
    ibinit = DLLibinit(dev%)
    Call copy_globals
End Function

Function ibist(ByVal dev%, ByVal v%) As Integer
    ibist = DLLibist(dev%, v%)
    Call copy_globals
End Function

Function iblines(ByVal dev%, ByRef lines%) As Integer
    Dim res&
    iblines = DLLiblines(dev%, res&)
    lines% = res&
    Call copy_globals
End Function

Function ibln(ByVal dev%, ByVal pad%, ByVal sad%, ByRef listener%) As Integer
    ibln = DLLibln(dev%, pad%, sad%, listener%)
    Call copy_globals
End Function

Function ibloc(ByVal dev%) As Integer
    ibloc = DLLibloc(dev%)
    Call copy_globals
End Function

Function ibonl(ByVal dev%, ByVal v%) As Integer
    ibonl = DLLibonl(dev%, v%)
    Call copy_globals
End Function

Function ibpad(ByVal dev%, ByVal v%) As Integer
    ibpad = DLLibpad(dev%, v%)
    Call copy_globals
End Function

Function ibpct(ByVal dev%) As Integer
    ibpct = DLLibpct(dev%)
    Call copy_globals
End Function

Function ibppc(ByVal dev%, ByVal v%) As Integer
    ibppc = DLLibppc(dev%, v%)
    Call copy_globals
End Function

Function ibrd(ByVal dev%, buf As String) As Integer
    Dim length&
    length = Len(buf)
    ibrd = DLLibrd(dev%, ByVal buf, length&)
    Call copy_globals
End Function

Function ibrda(ByVal dev%, buf As String) As Integer
    Dim length&
    length& = Len(buf)
    ' Call the 32-bit DLL.
    ibrda = DLLibrd(dev%, ByVal buf, length&)
  
' When Visual Basic remapping buffer problem solved, use this:
  '  ibrda = DLLibrda(dev%, buf$, length&)
    Call copy_globals
End Function

Function ibrdf(ByVal dev%, ByRef filename$) As Integer
    ibrdf = DLLibrdf(dev%, filename$)
    Call copy_globals
End Function

Function ibrdi(ByVal dev%, ByRef ibuf%(), ByVal cnt&) As Integer
    ibrdi = DLLibrd(dev%, ibuf%(0), cnt&)
    Call copy_globals
End Function

Function ibrdia(ByVal dev%, ByRef ibuf&(), ByVal cnt&) As Integer
' Call the 32-bit DLL.
    ibrdia = DLLibrd(dev%, ibuf&(0), cnt&)
' When Visual Basic remapping buffer problem solved, use this:
   ' ibrdia = DLLibrdia(dev%, ibuf&(0), cnt&)
    Call copy_globals
End Function

Function ibrpp(ByVal dev%, ByRef ppr%) As Integer
    Dim resp$
    resp$ = " "
    ibrpp = DLLibrpp(dev%, resp$)
    ppr = val(Left$(resp, 1&))
    Call copy_globals
End Function

Function ibrsc(ByVal dev%, ByVal v%) As Integer
    ibrsc = DLLibrsc(dev%, v%)
    Call copy_globals
End Function

Function ibrsp(ByVal dev%, ByRef rsp%) As Integer
    Dim resp$
    resp$ = " "
    ibrsp = DLLibrsp(dev%, resp$)
    rsp% = val(Left(resp$, 1))
    Call copy_globals
End Function

Function ibrsv(ByVal dev%, ByVal v%) As Integer
    ibrsv = DLLibrsv(dev%, v%)
    Call copy_globals
End Function

Function ibsad(ByVal dev%, ByVal v%) As Integer
    ibsad = DLLibsad(dev%, v%)
    Call copy_globals
End Function

Function ibsic(ByVal dev%) As Integer
    ibsic = DLLibsic(dev%)
    Call copy_globals
End Function

Function ibsre(ByVal dev%, ByVal v%) As Integer
    ibsre = DLLibsre(dev%, v%)
    Call copy_globals
End Function

Function ibstop(ByVal dev%) As Integer
    ibstop = DLLibstop(dev%)
    Call copy_globals
End Function

Function ibtmo(ByVal dev%, ByVal v%) As Integer
    ibtmo = DLLibtmo(dev%, v%)
    Call copy_globals
End Function

Function ibtrg(ByVal dev%) As Integer
    ibtrg = DLLibtrg(dev%)
    Call copy_globals
End Function

Function ibwait(ByVal dev%, ByVal mask%) As Integer
    ibwait = DLLibwait(dev%, mask%)
    Call copy_globals
End Function

Function ibwrt(ByVal dev%, ByRef buf$) As Integer
    Dim length&
    length& = Len(buf$)
    ibwrt = DLLibwrt(dev%, buf$, length&)
    Call copy_globals
End Function

Function ibwrta(ByVal dev%, ByRef buf$) As Integer
    Dim length&
    length& = Len(buf$)
    ' Call the 32-bit DLL.
    ibwrta = DLLibwrt(dev%, buf$, length&)
' When Visual Basic remapping buffer problem is solved, use this:
    'ibwrta = DLLibwrta(dev%, buf$, length&)
    Call copy_globals
End Function

Function ibwrtf(ByVal dev%, ByRef filename$) As Integer
    ibwrtf = DLLibwrtf(dev%, filename$)
    Call copy_globals
End Function

Function ibwrti(ByVal dev%, ByRef ibuf&(), cnt&) As Integer
    ibwrti = DLLibwrti(dev%, ibuf&(), cnt&)
    Call copy_globals
End Function

Function ibwrtia(ByVal dev%, ByRef ibuf&(), ByVal cnt&) As Integer
' Call the 32-bit DLL.
    ibwrtia = DLLibwrti(dev%, ibuf&(), cnt&)
' When Visual Basic remapping buffer problem is solved, use this:
    'ibwrtia = DLLibwrtia(dev%, ibuf&(), cnt&)
    Call copy_globals
End Function



'************************
' 488.2 Subroutines
'************************
Sub copy_globals()
    ibsta% = DLLThreadIbsta()
    iberr% = DLLThreadIberr()
    ibcnt% = DLLThreadIbcnt()
    ibcntl& = DLLThreadIbcntl()
End Sub

Sub AllSpoll(ByVal BD%, ByRef adrlist%(), ByRef results%())
    Call DLLAllSpoll(BD%, adrlist%(0), results%(0))
    Call copy_globals
End Sub

Sub DevClear(ByVal BD%, ByVal adr%)
    Call DLLDevClear(BD%, adr%)
    Call copy_globals
End Sub

Sub DevClearList(ByVal BD%, ByRef adrlist%())
    Call DLLDevClearList(BD%, adrlist%(0))
    Call copy_globals
End Sub

Sub EnableLocal(ByVal BD%, ByRef adrlist%())
    Call DLLEnableLocal(BD%, adrlist%(0))
    Call copy_globals
End Sub

Sub EnableRemote(ByVal BD%, ByRef adrlist%())
    Call DLLEnableRemote(BD%, adrlist%(0))
    Call copy_globals
End Sub

Sub FindLstn(ByVal BD As Integer, ByRef adrlist() As Integer, ByRef results() As Integer, ByVal limit As Integer)
    Call DLLFindLstn(BD, adrlist(0), results(0), limit)
    Call copy_globals
End Sub

Sub FindRQS(ByVal BD%, ByRef adrlist() As Integer, ByRef result%)
    Call DLLFindRQS(BD%, adrlist(0), result%)
    'result = Int(res&)
    Call copy_globals
End Sub

Sub PassControl(ByVal BD%, ByVal adr%)
    Call DLLPassControl(BD%, adr%)
    Call copy_globals
End Sub

Sub PPoll(ByVal BD%, ByRef result%)
    Dim res&
    Call DLLPPoll(BD%, result%)
    result = Int(res&)
    Call copy_globals
End Sub

Sub PPollConfig(ByVal BD%, ByVal adr%, ByVal lline%, ByVal sense%)
    Call DLLPPollConfig(BD%, adr%, lline%, sense%)
    Call copy_globals
End Sub

Sub PPollUnconfig(ByVal BD%, ByRef adrlist%())
    Call DLLPPollUnconfig(BD%, adrlist%(0))
    Call copy_globals
End Sub

Sub RcvRespMsg(ByVal BD%, ByRef buf$, ByVal term%)
    Dim length&
    length& = Len(buf$)
    Call DLLRcvRespMsg(BD%, buf$, length&, term%)
    Call copy_globals
End Sub

Sub ReadStatusByte(ByVal BD%, ByVal adr%, ByRef result%)
    Call DLLReadStatusByte(BD%, adr%, result%)
    Call copy_globals
End Sub

Sub Receive(ByVal BD%, ByVal adr%, ByRef buf$, ByVal term%)
    Dim length&
    length& = Len(buf$)
    Call DLLReceive(BD%, adr%, buf$, length&, term%)
    Call copy_globals
End Sub

Sub ReceiveSetup(ByVal BD%, ByVal adr%)
    Call DLLReceiveSetup(BD%, adr%)
    Call copy_globals
End Sub

Sub ResetSys(ByVal BD%, ByRef adrlist%())
    Call DLLResetSys(BD%, adrlist%(0))
    Call copy_globals
End Sub

Sub Send(ByVal BD%, ByVal adr%, ByRef buf$, ByVal term%)
    Dim length&
    length& = Len(buf$)
    Call DLLSend(BD%, adr%, buf$, length&, term%)
    Call copy_globals
End Sub

Sub SendCmds(ByVal BD%, ByRef cmdbuf$)
    Dim length&
    length& = Len(cmdbuf$)
    Call DLLSendCmds(BD%, cmdbuf$, length&)
    Call copy_globals
End Sub

Sub SendDataBytes(ByVal BD%, ByRef buf$, ByVal term%)
    Dim length&
    length& = Len(buf$)
    Call DLLSendDataBytes(BD%, buf$, length&, term%)
    Call copy_globals
End Sub

Sub SendIFC(ByVal BD%)
    Call DLLSendIFC(BD%)
    Call copy_globals
End Sub

Sub SendList(ByVal BD%, ByRef adr%(), ByRef buf$, ByVal term%)
    Dim length&
    length& = Len(buf$)
    Call DLLSendList(BD%, adr%(0), buf$, length&, term%)
    Call copy_globals
End Sub

Sub SendLLO(ByVal BD%)
    Call DLLSendLLO(BD%)
    Call copy_globals
End Sub

Sub SendSetup(ByVal BD%, ByRef adrlist%())
    Call DLLSendSetup(BD%, adrlist%(0))
    Call copy_globals
End Sub

Sub SetRWLS(ByVal BD%, ByRef adrlist%())
    Call DLLSetRWLS(BD%, adrlist%(0))
    Call copy_globals
End Sub

Sub TestSRQ(ByVal BD%, ByRef result%)
    Call DLLTestSRQ(ByVal BD%, result%)
    Call copy_globals
End Sub

Sub TestSys(ByVal BD%, ByRef adrlist%(), ByRef results%())
    Call DLLTestSys(BD%, adrlist%(0), results%(0))
    Call copy_globals
End Sub

Sub Trigger(ByVal BD%, ByVal adr%)
    Call DLLTrigger(BD%, adr%)
    Call copy_globals
End Sub

Sub TriggerList(ByVal BD%, ByRef adrlist%())
    Call DLLTriggerList(BD%, adrlist%(0))
    Call copy_globals
End Sub

Sub WaitSRQ(ByVal BD%, ByRef result%)
    Call DLLWaitSRQ(BD%, result%)
    Call copy_globals
End Sub




